import typing
import collections.abc
import typing_extensions
import numpy.typing as npt

def load_handler(_) -> None: ...
def register() -> None: ...
def unregister() -> None: ...
def update_factory_startup_grease_pencils() -> None: ...
def update_factory_startup_scenes() -> None: ...
def update_factory_startup_screens() -> None: ...
